@@ -2,9 +2,7 @@ from __future__ import absolute_import
 import os
 from .retina import RetinaFace
 from .arcnet import ArcFace
-import sys
-sys.path.append('..')
-from utils.tools import get_cfg, download_url
+from face_recognition.utils.tools import get_cfg, download_url
 
 __model_factory = {
     # face detection models
